EqualizerSettings class

Complete equalizer settings configuration

Constructors

EqualizerSettings({bool isEnabled = true, EqualizerPreset preset = EqualizerPreset.flat, List<EqualizerBand> bands = const [], double preampGain = 0.0, bool bassBoostEnabled = false, double bassBoostIntensity = 0.5, bool virtualizerEnabled = false, double virtualizerStrength = 0.5})
const
EqualizerSettings.fiveBand({EqualizerPreset preset = EqualizerPreset.flat, bool isEnabled = true})
Create default 5-band equalizer settings
factory
EqualizerSettings.fromJson(Map<String, dynamic> json)
Create from JSON map
factory
EqualizerSettings.tenBand({EqualizerPreset preset = EqualizerPreset.flat, bool isEnabled = true})
Create default 10-band equalizer settings
factory

Properties

bandCount int
Number of bands
no setter
bands List<EqualizerBand>
Individual band settings
final
bassBoostEnabled bool
Whether bass boost is enabled
final
bassBoostIntensity double
Bass boost intensity (0.0 to 1.0)
final
gains List<double>
Get all gains as a list
no setter
hashCode int
The hash code for this object.
no setterinherited
isEnabled bool
Whether the equalizer is enabled
final
isFiveBand bool
Whether this is a 5-band or 10-band equalizer
no setter
isModified bool
Whether any band is modified from flat
no setter
isTenBand bool
no setter
preampGain double
Pre-amplifier gain in dB (-12 to +12)
final
preset EqualizerPreset
Current preset being used
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
virtualizerEnabled bool
Whether virtualizer/surround is enabled
final
virtualizerStrength double
Virtualizer strength (0.0 to 1.0)
final

Methods

applyPreset(EqualizerPreset newPreset) EqualizerSettings
Apply a preset to the current bands
copyWith({bool? isEnabled, EqualizerPreset? preset, List<EqualizerBand>? bands, double? preampGain, bool? bassBoostEnabled, double? bassBoostIntensity, bool? virtualizerEnabled, double? virtualizerStrength}) EqualizerSettings
Create a copy with modified values
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() EqualizerSettings
Reset all bands to flat (0 dB)
toJson() Map<String, dynamic>
Convert to JSON map
toString() String
A string representation of this object.
override
withBandGain(int index, double gain) EqualizerSettings
Update a single band gain

Operators

operator ==(Object other) bool
The equality operator.
inherited