VoiceEffectSettings class

Complete voice effects settings for recording processing

Constructors

VoiceEffectSettings({bool isEnabled = true, NoiseReductionSettings noiseReduction = const NoiseReductionSettings(), VoiceEnhancementSettings voiceEnhancement = const VoiceEnhancementSettings(), DynamicsSettings dynamics = const DynamicsSettings(), List<VoiceEffectConfig> effectChain = const [], double outputGain = 0.0})
const
VoiceEffectSettings.broadcast()
Create settings for podcast/broadcast style
factory
VoiceEffectSettings.creatorVoice()
Create default settings optimized for creator voice recordings
factory
VoiceEffectSettings.fromJson(Map<String, dynamic> json)
factory
VoiceEffectSettings.minimal()
Create minimal processing settings
factory

Properties

dynamics DynamicsSettings
Dynamics processing (compressor/limiter)
final
effectChain List<VoiceEffectConfig>
List of active effects in processing order
final
hasActiveProcessing bool
Whether any processing is active
no setter
hashCode int
The hash code for this object.
no setterinherited
isEnabled bool
Whether voice processing is enabled
final
noiseReduction NoiseReductionSettings
Noise reduction settings
final
outputGain double
Output gain adjustment in dB
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
voiceEnhancement VoiceEnhancementSettings
Voice enhancement settings
final

Methods

addEffect(VoiceEffectConfig config) VoiceEffectSettings
Add an effect to the chain
copyWith({bool? isEnabled, NoiseReductionSettings? noiseReduction, VoiceEnhancementSettings? voiceEnhancement, DynamicsSettings? dynamics, List<VoiceEffectConfig>? effectChain, double? outputGain}) VoiceEffectSettings
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeEffect(VoiceEffect effect) VoiceEffectSettings
Remove an effect from the chain
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited