NativeEqualizerBridge class abstract

Abstract bridge for connecting the EqualizerController to a native platform equalizer (e.g. just_audio's AndroidEqualizer).

This interface lives in neom_sound so the module does NOT need to depend on just_audio. The concrete implementation is provided by neom_audio_player.

Implementers

Constructors

NativeEqualizerBridge()

Properties

bandCount Future<int>
Returns the number of bands supported by the native equalizer.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setBandGain(int index, double gain) Future<void>
Set the gain (in dB) for band at index.
setEnabled(bool enabled) Future<void>
Enable or disable the native equalizer effect.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited