VoiceProcessingResult class

Result of voice processing operation

Constructors

VoiceProcessingResult({required bool success, String? errorMessage, String? outputPath, List<int>? processedData, VoiceProcessingStats? stats})
const
VoiceProcessingResult.failure(String message)
factory
VoiceProcessingResult.success({String? outputPath, List<int>? processedData, VoiceProcessingStats? stats})
factory

Properties

errorMessage String?
Error message if failed
final
hashCode int
The hash code for this object.
no setterinherited
outputPath String?
Path to processed file (if file processing)
final
processedData List<int>?
Processed audio data (if data processing)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stats VoiceProcessingStats?
Processing statistics
final
success bool
Whether processing was successful
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited