onInit method

  1. @override
void onInit()
override

Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.

Implementation

@override
void onInit() async {
  super.onInit();
  List<dynamic> _  = Sint.arguments ?? [];
  try {
    await initializeRecorder();
  } catch(e, st) {
    NeomErrorLogger.recordError(e, st, module: 'neom_sound', operation: 'onInit');
  }

}