AuthorAudioPlayer class

Golden-styled audio player for author comments (Director's Cut). More compact design with golden accent colors.

Inheritance

Constructors

AuthorAudioPlayer({required String audioUrl, int? durationSeconds, String authorName = '', bool showAuthorName = true, VoidCallback? onPlaybackComplete, Key? key})
const

Properties

audioUrl String
URL of the audio file to play
final
authorName String
Author name to display
final
durationSeconds int?
Optional duration in seconds (if known beforehand)
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onPlaybackComplete VoidCallback?
Optional callback when playback completes
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showAuthorName bool
Whether to show the author name
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<AuthorAudioPlayer>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited