VoiceEffectsPanel class

Panel for configuring voice effects for creator recordings

Used in rooms for "behind the scenes" / "creator voice" feature.

Inheritance

Constructors

VoiceEffectsPanel({Key? key, VoiceProcessorController? controller, Color? backgroundColor, Color? accentColor, Color? labelColor, bool showPresets = true, bool showAdvanced = false, VoidCallback? onSettingsChanged})
const

Properties

accentColor Color?
Accent color
final
backgroundColor Color?
Background color
final
controller VoiceProcessorController?
Optional custom controller (uses Sint if not provided)
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelColor Color?
Label text color
final
onSettingsChanged → VoidCallback?
Callback when settings change
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showAdvanced bool
Whether to show advanced settings
final
showPresets bool
Whether to show quick presets
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited