DynamicsSettings class
Dynamics processing configuration (compressor/limiter)
Constructors
Properties
- attackMs → double
-
Attack time in milliseconds
final
- compressorEnabled → bool
-
Whether compressor is enabled
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- limiterEnabled → bool
-
Whether limiter is enabled
final
- limiterThreshold → double
-
Limiter threshold in dB
final
- makeupGain → double
-
Makeup gain in dB
final
- ratio → double
-
Compression ratio (e.g., 4.0 = 4:1)
final
- releaseMs → double
-
Release time in milliseconds
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- threshold → double
-
Threshold in dB
final
Methods
-
copyWith(
{bool? compressorEnabled, double? threshold, double? ratio, double? attackMs, double? releaseMs, double? makeupGain, bool? limiterEnabled, double? limiterThreshold}) → DynamicsSettings -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited