VoiceEffectConfig class
Configuration for a single voice effect
Constructors
-
VoiceEffectConfig({required VoiceEffect effect, double intensity = 0.5, bool isEnabled = true, Map<
String, double> parameters = const {}}) -
const
-
VoiceEffectConfig.fromJson(Map<
String, dynamic> json) -
factory
Properties
- effect → VoiceEffect
-
The effect type
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- intensity → double
-
Effect intensity (0.0 to 1.0)
final
- isEnabled → bool
-
Whether this effect is enabled
final
-
parameters
→ Map<
String, double> -
Additional parameters specific to the effect
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{VoiceEffect? effect, double? intensity, bool? isEnabled, Map< String, double> ? parameters}) → VoiceEffectConfig -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited