VoiceProcessingStats class
Statistics from voice processing
Constructors
Properties
- durationMs → int
-
Duration of audio processed in milliseconds
final
- gainAppliedDb → double
-
Amount of gain applied in dB
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputPeakDb → double
-
Input peak level in dB
final
- isFasterThanRealTime → bool
-
Whether processing was faster than real-time
no setter
- noiseReductionDb → double
-
Amount of noise reduced in dB
final
- outputPeakDb → double
-
Output peak level in dB
final
- processingSpeedRatio → double
-
Processing speed ratio (1.0 = real-time)
no setter
- processingTimeMs → int
-
Processing time in milliseconds
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited