VoiceEffect enum
Voice effects for audio processing
Effects that can be applied to voice recordings for the "behind the scenes" / "creator voice" feature in rooms
- Inheritance
- Available extensions
Values
- none → const VoiceEffect
-
No effect applied
- noiseReduction → const VoiceEffect
-
Removes background noise
- voiceEnhancement → const VoiceEffect
-
Enhances voice clarity and presence
- broadcast → const VoiceEffect
-
Professional broadcast/radio sound
- warmth → const VoiceEffect
-
Warm, intimate sound
- brightness → const VoiceEffect
-
Bright, clear sound
- deepVoice → const VoiceEffect
-
Deep, resonant voice
- telephone → const VoiceEffect
-
Telephone/radio effect
- echo → const VoiceEffect
-
Echo/reverb effect
- hallReverb → const VoiceEffect
-
Large hall reverb
- roomReverb → const VoiceEffect
-
Small room reverb
- whisper → const VoiceEffect
-
Whisper effect
- robotic → const VoiceEffect
-
Robot/metallic voice
- chipmunk → const VoiceEffect
-
Slight pitch up
- deepPitch → const VoiceEffect
-
Slight pitch down
- deBreath → const VoiceEffect
-
Removes breathing sounds
- dePlosive → const VoiceEffect
-
Removes plosives (p, b sounds)
- normalizer → const VoiceEffect
-
Automatic gain control
- compressor → const VoiceEffect
-
Compresses dynamic range
- limiter → const VoiceEffect
-
Soft limiting
Properties
- description → String
-
Available on VoiceEffect, provided by the VoiceEffectExtension extension
Description for UIno setter - displayName → String
-
Available on VoiceEffect, provided by the VoiceEffectExtension extension
Display name for UIno setter - hashCode → int
-
The hash code for this object.
no setterinherited
- iconName → String
-
Available on VoiceEffect, provided by the VoiceEffectExtension extension
Icon name for UIno setter - index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- isCreativeEffect → bool
-
Available on VoiceEffect, provided by the VoiceEffectExtension extension
Whether this is a creative/fun effectno setter - isProcessingEffect → bool
-
Available on VoiceEffect, provided by the VoiceEffectExtension extension
Whether this is a processing effect (vs creative effect)no setter - isToneAdjustment → bool
-
Available on VoiceEffect, provided by the VoiceEffectExtension extension
Whether this is a tone adjustmentno setter - name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
VoiceEffect> - A constant List of the values in this enum, in order of their declaration.